@@ -37,6 +37,14 @@
 #include <errno.h>
 #include <fcntl.h>
 
+int mpd_wait_for_answer(MpdObj *);
+int mpd_send_single_cmd(MpdObj*, char*);
+void send_complex_cmd(MpdObj*, char*, void (*)(), void *);
+void parse_status_answer(MpdObj*, void*);
+void parse_one_song(MpdObj*, void*);
+void parse_playlistinfo_answer(MpdObj*, void*);
+void parse_outputs_answer(MpdObj*, void*);
+
 MpdObj* mpd_new(char* host, int port, char* pass)
 {
    MpdObj* mo = g_new0(MpdObj,1);
@@ -182,8 +190,8 @@ int mpd_wait_for_answer(MpdObj *mo)
 {
    struct timeval tv;
    int err,nbread;
-   err = nbread = 0;
    fd_set fds;
+   err = nbread = 0;
 
    DBG("!");
 
@@ -460,6 +468,10 @@ void parse_outputs_answer(MpdObj *mo, void *param)
          g_strfreev(tokens);
       }
       md->nb++;
+      if (strcmp(lines[i],"OK")) {
+         /* make room for the next output ptr */
+         md->alloutputs = g_renew(mpd_Output*, md->alloutputs, md->nb + 1);
+      }
    }
    g_strfreev(lines);
 }
@@ -667,10 +679,11 @@ int mpd_check_error(MpdObj* mo)
 
 void mpd_send_password(MpdObj* mo)
 {
-   DBG("!");
    char outbuf[256];
+   int wrote;
+   DBG("!");
    /* write password 'password' to socket */
-   int wrote = snprintf(outbuf, sizeof(outbuf), "password %s\n",mo->pass);
+   wrote = snprintf(outbuf, sizeof(outbuf), "password %s\n",mo->pass);
    if (wrote > 255) {
 	/* the password is too long to fit though there doesn't seem to be a
 	 * nice way to report this error :-/ */
